plug_metadata_logger v0.1.0 PlugMetadataLogger
Plug Middleware to log request and response into in metadata.
It puts a map into metadata, so logger formatter MUST handle it.
Otherwise it will raise Protocol.UndefinedError
Link to this section Summary
Link to this section Functions
Link to this function
call(conn, opts)
Callback implementation for Plug.call/2.
Link to this function
init(opts)
Callback implementation for Plug.init/1.